@@ -32,7 +32,7 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
         if response.status_code == 200:
             return response.json()
         elif response.status_code != 204:
-            raise ConnectionAbortedError("Checking hash not worked. {0}".format(response))
+            raise ConnectionAbortedError("Checking hash not worked. {0}".format(response.content))
         else:
             print("Model not found on server. Uploading now...")
         task = Task(compileApi(file, params))
